@@ -17,6 +17,8 @@ from Crypto.Random import get_random_bytes
 from Crypto.Cipher.AES import AESCipher, MODE_CBC, block_size
 from secretstorage.dhcrypto import long_to_bytes, bytes_to_long
 
+SERVICE_IFACE = SS_PREFIX + 'Service'
+
 class InterfaceWrapper(dbus.Interface):
 	"""Wraps :cls:`dbus.Interface` class and replaces some D-Bus exceptions
 	with :doc:`SecretStorage exceptions <exceptions>`."""
@@ -141,9 +143,24 @@ def exec_prompt_qt(bus, prompt):
 	app.exec_()
 	return result[0], result[1]
 
-# Compatibility aliases
-exec_prompt_async_glib = exec_prompt_glib
-exec_prompt_async_qt   = exec_prompt_qt
+def unlock_objects(bus, paths, callback=None):
+	"""Requests unlocking objects specified in `paths`. If `callback`
+	is specified, calls it when unlocking is complete (see
+	:func:`exec_prompt` description for details).
+	Otherwise, uses the loop from GLib API and returns a boolean
+	representing whether the operation was dismissed."""
+	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
+	service_iface = InterfaceWrapper(service_obj, SERVICE_IFACE)
+	unlocked_paths, prompt = service_iface.Unlock(paths, signature='ao')
+	unlocked_paths = list(unlocked_paths)  # Convert from dbus.Array
+	if len(prompt) > 1:
+		if callback:
+			exec_prompt(bus, prompt, callback)
+		else:
+			return exec_prompt_glib(bus, prompt)[0]
+	elif callback:
+		# We still need to call it.
+		callback(False, unlocked_paths)
 
 def to_unicode(string):
 	"""Converts D-Bus string to unicode string."""
