@@ -15,7 +15,7 @@ class ExceptionsTest(unittest.TestCase):
 	@classmethod
 	def setUpClass(cls):
 		cls.bus = secretstorage.dbus_init(main_loop=False)
-		cls.collection = secretstorage.Collection(cls.bus)
+		cls.collection = secretstorage.get_any_collection(cls.bus)
 
 	def test_double_deleting(self):
 		item = self.collection.create_item('MyItem',
